@@ -9,7 +9,11 @@ from examtool.cli.utils import exam_name_option
 
 
 def time(timestamp):
-    return datetime.utcfromtimestamp(timestamp).replace(tzinfo=pytz.utc).astimezone(pytz.timezone("America/Los_Angeles"))
+    return (
+        datetime.utcfromtimestamp(timestamp)
+        .replace(tzinfo=pytz.utc)
+        .astimezone(pytz.timezone("America/Los_Angeles"))
+    )
 
 
 @click.command()
@@ -37,12 +41,14 @@ def logs(email, exam, roster):
         for record in get_logs(exam=exam, email=email):
             ref = time(record.pop("timestamp"))
             times.append([ref, next(iter(record.keys())), next(iter(record.values()))])
-        print("\n".join(str(x) + " " + str(y) + " " + str(z) for x, y, z in sorted(times)))
+        print(
+            "\n".join(str(x) + " " + str(y) + " " + str(z) for x, y, z in sorted(times))
+        )
 
     all_students.sort(key=lambda x: x[0])
 
     print("\n".join(str(x) + " " + str(y) for x, y in all_students))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     logs()
